#! /bin/sh

#
# open-xdgmenu
# Tarball Generator
#
# Copyright (C) 2007-2008 Siegfried-Angel Gevatter Pujals <rainct@ubuntu.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

if [ $# -ne 1 ]
then
	echo "Usage: $0 <version>"
	exit 1
fi

# Define variables
APPNAME=openbox-xdgmenu
TMPDIR=/tmp/$APPNAME
CURDIR=$(pwd)
VERSION=$1

# Create temporal directory
echo "Copying files..."
mkdir -p $TMPDIR/$APPNAME-$VERSION

# Copy files
cp -r * $TMPDIR/$APPNAME-$VERSION

# Remove unneeded stuff
cd $TMPDIR/$APPNAME-$VERSION || exit 1
rm -f .hidden *.~1~ *.o openbox-xdgmenu release.sh
rm -rf .bzr .bzrignore debian releases

# Generate tarball
echo "Generating tarball..."
cd $TMPDIR
tar -czf $APPNAME-$VERSION.tar.gz $APPNAME-$VERSION

# Copy generated tarball
cd $CURDIR
if [ -e releases ]
then
	if [ ! -d ]; then
		echo "$0: error: can't create directory «releases», a file with the same name already exists."
		rm -rf $TMPDIR; exit 1
	fi
else
	mkdir releases
fi
cp $TMPDIR/$APPNAME-$VERSION.tar.gz releases/

# Print a success message
echo "File «./releases/$APPNAME-$VERSION.tar.gz» successfully generated."

# Clean up
echo "Cleaning up..."
cd $CURDIR
rm -rf $TMPDIR
